/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#include "includes.h"

/*
 * Initializes control task.
 */
void initHall3(HALL3 *aV)
{
   //Enable EALLOW
   EALLOW;

   //Configure ECAP1/2/3 as GPIO-inputs (GPIO24/25/26) for Piccolo B
   GpioCtrlRegs.GPAMUX2.bit.GPIO24 = 0; //GPIO24 is ECAP1 - A
   GpioCtrlRegs.GPAMUX2.bit.GPIO25 = 0; //GPIO25 is ECAP2 - B
   GpioCtrlRegs.GPAMUX2.bit.GPIO26 = 0; //GPIO26 is ECAP3 - C
   //Config GPIO24/25/26 as inputs
   GpioCtrlRegs.GPADIR.bit.GPIO24 = 0;  //GPIO24 is ECAP1 - A
   GpioCtrlRegs.GPADIR.bit.GPIO25 = 0;  //GPIO25 is ECAP2 - B
   GpioCtrlRegs.GPADIR.bit.GPIO26 = 0;  //GPIO26 is ECAP3 - C

   EDIS;
   //Disable EALLOW
   determineHALL3State(aV);
   aV->HallGpioBuffer = aV->HallGpio;     //Init with current ECAP/GPIO logic levels
   aV->HallGpioAccepted = aV->HallGpio;   //Init with current ECAP/GPIO logic levels
}

/*
 * Determine HALL State
 */
void determineHALL3State(HALL3 *aV)
{
   Uint32 temp;
   Uint16 HallGpioBitA, HallGpioBitB, HallGpioBitC;

   //temp.2-0 = GPIO26.GPIO25.GPIO24
   temp = (GpioDataRegs.GPADAT.all >> 24) & 0x00000007; //read all three GPIOs at once
   HallGpioBitA = (temp & 0x00000001);                  // save GPIO24 - A
   HallGpioBitB = (temp & 0x00000002) >> 1;             // save GPIO25 - B
   HallGpioBitC = (temp & 0x00000004) >> 2;             // save GPIO26 - C
   //Shift for HallGpio calculation
   HallGpioBitA = HallGpioBitA;
   HallGpioBitB = HallGpioBitB << 1;
   HallGpioBitC = HallGpioBitC << 2;

   //***************************************************************************************************************
   //HallGPIO is a Probed Variable -> write access needs to be replaced by SET_OPROBE

   //Original Code:

   //v->HallGpio = HallGpioBitA + HallGpioBitB + HallGpioBitC;

   //Replacement:

   SET_OPROBE(aV->HallGpio, HallGpioBitA + HallGpioBitB + HallGpioBitC);

   //***************************************************************************************************************
}
