/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#include "includes.h"

struct ANALOG_INPUTS AIn;
struct ADC_OPROBES AdcOvrProbes;

#define ADC_usDELAY 10000L
extern void DSP28x_usDelay(unsigned long aCount);
static void PowerupADC()
{
	EALLOW;
	SysCtrlRegs.PCLKCR0.bit.ADCENCLK = 1; // Enable ADC peripheral clock

	PLX_DELAY_US(ADC_usDELAY);
	AdcRegs.ADCCTL1.all = 0x4000; // Reset ADC
	asm(" NOP ");
	asm(" NOP ");

	AdcRegs.ADCCTL1.bit.ADCBGPWD = 1; // Power up band gap

	PLX_DELAY_US(ADC_usDELAY);

	AdcRegs.ADCCTL1.bit.ADCREFSEL = 0;
	AdcRegs.ADCCTL1.bit.ADCREFPWD = 1; // Power up reference
	AdcRegs.ADCCTL1.bit.ADCPWDN = 1; // Power up rest of ADC
	AdcRegs.ADCCTL1.bit.ADCENABLE = 1; // Enable ADC

	asm(" RPT#100 || NOP");

	AdcRegs.ADCCTL1.bit.INTPULSEPOS = 1;
	AdcRegs.ADCCTL1.bit.TEMPCONV = 0;

	PLX_DELAY_US(ADC_usDELAY);
	EDIS;
}

void InitADC()
{
	PowerupADC();

	EALLOW;
    AdcRegs.ADCCTL2.bit.ADCNONOVERLAP = 1;	// Enable non-overlap mode
 	EDIS;

	// Configure channels
	EALLOW;

	AdcRegs.ADCSAMPLEMODE.all = 0; // no simultaneous sampling
	AdcRegs.SOCPRICTL.bit.SOCPRIORITY = 0; // round-robin - now high priority channels

	AdcRegs.ADCSOC0CTL.bit.CHSEL = 1; // ChSelect: ADC A1-> Phase U Current
	AdcRegs.ADCSOC0CTL.bit.TRIGSEL = 5; // Set SOC0 start trigger on EPWM1A, SOCA
	AdcRegs.ADCSOC0CTL.bit.ACQPS = 6; // Set SOC0 S/H Window to 7 ADC Clock Cycles, (6 ACQPS plus 1)

	AdcRegs.ADCSOC1CTL.bit.CHSEL = 9; // ChSelect: ADC B1-> Phase V Current
	AdcRegs.ADCSOC1CTL.bit.TRIGSEL = 5;
	AdcRegs.ADCSOC1CTL.bit.ACQPS = 6;

	AdcRegs.ADCSOC2CTL.bit.CHSEL = 10; // ChSelect: ADC B2-> DC Bus Voltage
	AdcRegs.ADCSOC2CTL.bit.TRIGSEL = 5;
	AdcRegs.ADCSOC2CTL.bit.ACQPS = 6;

	EDIS;

	// default offset calibration
    AIn.IuOffset = 0x800;
    AIn.IvOffset = 0x800;
}

void InitPWM(uint16_t aPeriod){
	EALLOW;
	SysCtrlRegs.PCLKCR1.bit.EPWM1ENCLK = 1; // ePWM1
	SysCtrlRegs.PCLKCR1.bit.EPWM2ENCLK = 1; // ePWM2
	SysCtrlRegs.PCLKCR1.bit.EPWM3ENCLK = 1; // ePWM3
	SysCtrlRegs.PCLKCR1.bit.EPWM4ENCLK = 1; // ePWM4
	SysCtrlRegs.PCLKCR1.bit.EPWM5ENCLK = 1;	// ePWM5
	SysCtrlRegs.PCLKCR1.bit.EPWM6ENCLK = 1;	// ePWM6
	SysCtrlRegs.PCLKCR1.bit.EPWM7ENCLK = 1;	// ePWM7
	SysCtrlRegs.PCLKCR1.bit.EPWM8ENCLK = 1;	// ePWM8
	EDIS;

	// EPWM Module 1 config
	EPwm1Regs.TBPRD = aPeriod;
	EPwm1Regs.TBPHS.half.TBPHS = 0; // Set Phase register to zero
	EPwm1Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN; // Symmetrical mode
	EPwm1Regs.TBCTL.bit.PHSEN = TB_DISABLE; // Master module
	EPwm1Regs.TBCTL.bit.PRDLD = TB_SHADOW;
	EPwm1Regs.TBCTL.bit.SYNCOSEL = TB_CTR_ZERO; // Sync down-stream module
	EPwm1Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
	EPwm1Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
	EPwm1Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm1Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm1Regs.AQCTLA.bit.CAU = AQ_SET; // set actions for EPWM1A
	EPwm1Regs.AQCTLA.bit.CAD = AQ_CLEAR;
	EPwm1Regs.DBCTL.bit.OUT_MODE = DB_FULL_ENABLE; // enable Dead-band module
	EPwm1Regs.DBCTL.bit.POLSEL = DB_ACTV_HIC; // Active Hi complementary
	EPwm1Regs.DBFED = 50; // FED = 50 TBCLKs
	EPwm1Regs.DBRED = 50; // RED = 50 TBCLKs

	// EPWM Module 2 config
	EPwm2Regs.TBPRD = aPeriod;
	EPwm2Regs.TBPHS.half.TBPHS = 0; // Set Phase register to zero
	EPwm2Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN; // Symmetrical mode
	EPwm2Regs.TBCTL.bit.PHSEN = TB_ENABLE; // Slave module
	EPwm2Regs.TBCTL.bit.PRDLD = TB_SHADOW;
	EPwm2Regs.TBCTL.bit.SYNCOSEL = TB_SYNC_IN; // sync flow-through
	EPwm2Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
	EPwm2Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
	EPwm2Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm2Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm2Regs.AQCTLA.bit.CAU = AQ_SET; // set actions for EPWM2A
	EPwm2Regs.AQCTLA.bit.CAD = AQ_CLEAR;
	EPwm2Regs.DBCTL.bit.OUT_MODE = DB_FULL_ENABLE; // enable Dead-band module
	EPwm2Regs.DBCTL.bit.POLSEL = DB_ACTV_HIC; // Active Hi complementary
	EPwm2Regs.DBFED = 50; // FED = 50 TBCLKs
	EPwm2Regs.DBRED = 50; // RED = 50 TBCLKs

	// EPWM Module 3 config
	EPwm3Regs.TBPRD = aPeriod;
	EPwm3Regs.TBPHS.half.TBPHS = 0; // Set Phase register to zero
	EPwm3Regs.TBCTL.bit.CTRMODE = TB_COUNT_UPDOWN; // Symmetrical mode
	EPwm3Regs.TBCTL.bit.PHSEN = TB_ENABLE; // Slave module
	EPwm3Regs.TBCTL.bit.PRDLD = TB_SHADOW;
	EPwm3Regs.TBCTL.bit.SYNCOSEL = TB_SYNC_IN; // sync flow-through
	EPwm3Regs.CMPCTL.bit.SHDWAMODE = CC_SHADOW;
	EPwm3Regs.CMPCTL.bit.SHDWBMODE = CC_SHADOW;
	EPwm3Regs.CMPCTL.bit.LOADAMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm3Regs.CMPCTL.bit.LOADBMODE = CC_CTR_ZERO; // load on CTR=Zero
	EPwm3Regs.AQCTLA.bit.CAU = AQ_SET; // set actions for EPWM3A
	EPwm3Regs.AQCTLA.bit.CAD = AQ_CLEAR;
	EPwm3Regs.DBCTL.bit.OUT_MODE = DB_FULL_ENABLE; // enable Dead-band module
	EPwm3Regs.DBCTL.bit.POLSEL = DB_ACTV_HIC; // Active Hi complementary
	EPwm3Regs.DBFED = 50; // FED = 50 TBCLKs
	EPwm3Regs.DBRED = 50;
}

void InitGPIO(){
	EALLOW;

	//  GPIO-34 - PIN FUNCTION = LED3 on controlCARD
	GpioCtrlRegs.GPBMUX1.bit.GPIO34 = 0;	// 0=GPIO,  1=COMP2OUT,  2=Resv,  3=COMP3OUT
	GpioCtrlRegs.GPBDIR.bit.GPIO34 = 1;		// 1=OUTput,  0=INput
	GpioDataRegs.GPBCLEAR.bit.GPIO34 = 1;

	EDIS;
}

