%% Vehicle Parameters (Nissan Leaf Parameters)
EV.m_v=1521; % [kg] - Wheel mass
EV.g=9.81; % [m/s^2] - Acceleration due to gravity
EV.F_v=EV.m_v*EV.g; % [N] - Weight
EV.v_init=0; %[m/s] Initial vehicle velocity
EV.l_base=2.7; % [m] - Length of vehicle wheelbase
EV.h=1.54/(2*1.4071); % [m] - Height of vehicle center of gravity (CG) = Axel Width/(2*SSF)
EV.l_f=0.56*EV.l_base; % [m] - Distance of CG from front axle
EV.l_r=EV.l_base-EV.l_f; % [m] - Distance of CG from rear axle

%% Mechanical Motor and gear parameters
P.Jm = 0.014; % [kgm^2] - Motor inertia
P.w_m_init=0; % [rad/s] - Initial motor speed
P.g_ratio=6; % [1] - Gear ratio
P.Ks = 1800/1.1; % [Nm/rad] - Rotor shaft stiffness
P.Ds = 18; % [Nms/rad] - Rotor damping coefficient
P.gear_bl = 0;% [rads] - Gear backlash

%% Wheel Parameters 
P.m_w = 11.38; % [kg] - Wheel mass
P.rw = 21.75*0.0254/2;;% [m] - Wheel radius
P.J_w = P.m_w*P.rw^2; %[kgm^2] - Wheel inertia
P.w_w_init=P.w_m_init/P.g_ratio; % [rad/s] - Initial wheel speed
P.u_rr=0.01; % [1] - Rolling resistance
P.w_fric=P.u_rr*EV.F_v/2*P.rw; % [Nm] - Breakaway & Coulomb wheel friction torque

P.Jv = EV.m_v*(P.rw/P.g_ratio)^2;
P.J = P.Jm + P.Jv;
A.Tpe = 1/100;

%% Magic Formula Coefficients
EV.Dx=3000; % [N]
EV.Cx=1.6; % [1]
EV.Bx=12.5; % [1]
EV.dx=EV.Dx/(600*EV.g); % [1] - linearized coefficient

%% Slip Calculation coefficients
EV.lambda_init=0; % [1] - Initial slip
EV.sigma_min=0.02; % [m] - Minimum tire relaxation length
EV.sigma_k0=0.2; % [m] - Low speed relaxation length filter coefficient
EV.k_V_low0=770; % [Ns/m] - Low speed filtering coefficient

%% Delay
EV.R1_Tmes = 0.5e-3; % [s] - Delay in the change of vehicle pitch angle


%% Active damping
Rw.Ts = 1/1000;

Rw.J = P.Jv;
Rw.Gd = 10;

Rw.Ti = 36/P.Ks;
Rw.Tn = Rw.Gd*(36/P.Ks * P.Ds/36);

Rw.Kp = (Rw.Tn - Rw.Ts/2)/Rw.Ti;
Rw.Ki = Rw.Ts/Rw.Ti;

Rw.Tmax_p = 100;
Rw.Tmax_n = -100;

% Electric drive
D.Vbat = 400; % battery voltage
D.Cbus = 2.5e-3; % bus capacitance
D.Rbus = 0.001; % bus cap ESR

%% speed
D.Wm = 2*pi*1000/60; % radiants per second

% PWM and sampling
D.fpwm = 10000;
D.fs = D.fpwm;
D.Tpwm = 1/D.fpwm;
D.Ts = 1/D.fs;

D.Tcs = 1/(2*pi*100000); % current sensor bandwidth

s = 4;
%% Electrical Motor Parameters 
M.Rs = 1.24/2/s;
M.Ld = 0.00414/s^2; 
M.Lq = 0.00414/s^2;
M.Lss = (M.Ld + M.Lq)/50/s^2;
M.P = 4.0;
M.Psir  = 0.05;

%% Initial conditions assuming initial position = 0 and Y connection
M.Id0 = 0;
M.Iq0 = 0;
M.thm0 = 0;
% assuming initial position = 0
M.is0 = [M.Id0 M.Iq0];

%% equivalent small time-constant (used for current regulator tuning)
Ri.Ts = D.Ts;
Ri.Tcalc = 0.5/D.fs;
Ri.Ta = 0.5/D.fpwm;
Ri.Tsh = 0.5/D.fs;
Ri.Tp = Ri.Tcalc + Ri.Ta + Ri.Tsh + D.Tcs;

%% current regulator tuning
Ri.Ra = 0.0;
Ri.R = M.Rs + Ri.Ra;

Ri.Tii = 2/Ri.R*Ri.Tp;
Ri.Tni_D = M.Ld/Ri.R;
Ri.Tni_Q = M.Lq/Ri.R;

Ki = 1/Ri.Tii;
Kp_D = Ri.Tni_D/Ri.Tii;
Kp_Q = Ri.Tni_Q/Ri.Tii;

%% current regulator
Ri.Ra = Ri.Ra;
Ri.Vd0 = M.Rs * M.Iq0;
Ri.Vq0 = M.Rs * M.Id0 + D.Wm*M.P/2*(M.Psir+M.Ld*M.Id0);
Ri.V0 = [Ri.Vd0 Ri.Vq0];
Ri.Tcalc = Ri.Tcalc;
Ri.Ts = Ri.Ts;
Ri.Tn_D = Ri.Tni_D;
Ri.Tn_Q = Ri.Tni_Q;
Ri.Ti = Ri.Tii;
Ri.Kp = [Kp_D Kp_Q];
Ri.Ki = [Ki Ki];